Documentation
¶
Index ¶
- type ClusterSourceLister
- type ClusterSourceListerExpansion
- type ClusterSummaryLister
- type ClusterSummaryListerExpansion
- type ClusterTargetLister
- type ClusterTargetListerExpansion
- type PodChaperonLister
- type PodChaperonListerExpansion
- type PodChaperonNamespaceLister
- type PodChaperonNamespaceListerExpansion
- type SourceLister
- type SourceListerExpansion
- type SourceNamespaceLister
- type SourceNamespaceListerExpansion
- type TargetLister
- type TargetListerExpansion
- type TargetNamespaceLister
- type TargetNamespaceListerExpansion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterSourceLister ¶ added in v0.10.0
type ClusterSourceLister interface {
// List lists all ClusterSources in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.ClusterSource, err error)
// Get retrieves the ClusterSource from the index for a given name.
Get(name string) (*v1alpha1.ClusterSource, error)
ClusterSourceListerExpansion
}
ClusterSourceLister helps list ClusterSources.
func NewClusterSourceLister ¶ added in v0.10.0
func NewClusterSourceLister(indexer cache.Indexer) ClusterSourceLister
NewClusterSourceLister returns a new ClusterSourceLister.
type ClusterSourceListerExpansion ¶ added in v0.10.0
type ClusterSourceListerExpansion interface{}
ClusterSourceListerExpansion allows custom methods to be added to ClusterSourceLister.
type ClusterSummaryLister ¶ added in v0.10.0
type ClusterSummaryLister interface {
// List lists all ClusterSummaries in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.ClusterSummary, err error)
// Get retrieves the ClusterSummary from the index for a given name.
Get(name string) (*v1alpha1.ClusterSummary, error)
ClusterSummaryListerExpansion
}
ClusterSummaryLister helps list ClusterSummaries.
func NewClusterSummaryLister ¶ added in v0.10.0
func NewClusterSummaryLister(indexer cache.Indexer) ClusterSummaryLister
NewClusterSummaryLister returns a new ClusterSummaryLister.
type ClusterSummaryListerExpansion ¶ added in v0.10.0
type ClusterSummaryListerExpansion interface{}
ClusterSummaryListerExpansion allows custom methods to be added to ClusterSummaryLister.
type ClusterTargetLister ¶ added in v0.10.0
type ClusterTargetLister interface {
// List lists all ClusterTargets in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.ClusterTarget, err error)
// Get retrieves the ClusterTarget from the index for a given name.
Get(name string) (*v1alpha1.ClusterTarget, error)
ClusterTargetListerExpansion
}
ClusterTargetLister helps list ClusterTargets.
func NewClusterTargetLister ¶ added in v0.10.0
func NewClusterTargetLister(indexer cache.Indexer) ClusterTargetLister
NewClusterTargetLister returns a new ClusterTargetLister.
type ClusterTargetListerExpansion ¶ added in v0.10.0
type ClusterTargetListerExpansion interface{}
ClusterTargetListerExpansion allows custom methods to be added to ClusterTargetLister.
type PodChaperonLister ¶
type PodChaperonLister interface {
// List lists all PodChaperons in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.PodChaperon, err error)
// PodChaperons returns an object that can list and get PodChaperons.
PodChaperons(namespace string) PodChaperonNamespaceLister
PodChaperonListerExpansion
}
PodChaperonLister helps list PodChaperons.
func NewPodChaperonLister ¶
func NewPodChaperonLister(indexer cache.Indexer) PodChaperonLister
NewPodChaperonLister returns a new PodChaperonLister.
type PodChaperonListerExpansion ¶
type PodChaperonListerExpansion interface{}
PodChaperonListerExpansion allows custom methods to be added to PodChaperonLister.
type PodChaperonNamespaceLister ¶
type PodChaperonNamespaceLister interface {
// List lists all PodChaperons in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.PodChaperon, err error)
// Get retrieves the PodChaperon from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.PodChaperon, error)
PodChaperonNamespaceListerExpansion
}
PodChaperonNamespaceLister helps list and get PodChaperons.
type PodChaperonNamespaceListerExpansion ¶
type PodChaperonNamespaceListerExpansion interface{}
PodChaperonNamespaceListerExpansion allows custom methods to be added to PodChaperonNamespaceLister.
type SourceLister ¶ added in v0.10.0
type SourceLister interface {
// List lists all Sources in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Source, err error)
// Sources returns an object that can list and get Sources.
Sources(namespace string) SourceNamespaceLister
SourceListerExpansion
}
SourceLister helps list Sources.
func NewSourceLister ¶ added in v0.10.0
func NewSourceLister(indexer cache.Indexer) SourceLister
NewSourceLister returns a new SourceLister.
type SourceListerExpansion ¶ added in v0.10.0
type SourceListerExpansion interface{}
SourceListerExpansion allows custom methods to be added to SourceLister.
type SourceNamespaceLister ¶ added in v0.10.0
type SourceNamespaceLister interface {
// List lists all Sources in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Source, err error)
// Get retrieves the Source from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Source, error)
SourceNamespaceListerExpansion
}
SourceNamespaceLister helps list and get Sources.
type SourceNamespaceListerExpansion ¶ added in v0.10.0
type SourceNamespaceListerExpansion interface{}
SourceNamespaceListerExpansion allows custom methods to be added to SourceNamespaceLister.
type TargetLister ¶ added in v0.10.0
type TargetLister interface {
// List lists all Targets in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.Target, err error)
// Targets returns an object that can list and get Targets.
Targets(namespace string) TargetNamespaceLister
TargetListerExpansion
}
TargetLister helps list Targets.
func NewTargetLister ¶ added in v0.10.0
func NewTargetLister(indexer cache.Indexer) TargetLister
NewTargetLister returns a new TargetLister.
type TargetListerExpansion ¶ added in v0.10.0
type TargetListerExpansion interface{}
TargetListerExpansion allows custom methods to be added to TargetLister.
type TargetNamespaceLister ¶ added in v0.10.0
type TargetNamespaceLister interface {
// List lists all Targets in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.Target, err error)
// Get retrieves the Target from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.Target, error)
TargetNamespaceListerExpansion
}
TargetNamespaceLister helps list and get Targets.
type TargetNamespaceListerExpansion ¶ added in v0.10.0
type TargetNamespaceListerExpansion interface{}
TargetNamespaceListerExpansion allows custom methods to be added to TargetNamespaceLister.